@@ -57,6 +57,8 @@
 
 #include "search.h"
 
+#include "gtk3_compat.h"
+
 
 #define APP_SCITEPROJ_ERROR g_quark_from_static_string("APP_GUI_ERROR")
 
@@ -1134,28 +1136,28 @@ gboolean key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer userData)
 {
 	switch (event->keyval) 
 	{
-		case GDK_BackSpace: 
+		case GDK_KEY_BackSpace: 
 		{
 			debug_printf((gchar*)"key_press_cb: keyval = %d = GDK_BackSpace, hardware_keycode = %d\n", event->keyval, event->hardware_keycode);
 			break;
 		}
 		
-		case GDK_Delete: 
+		case GDK_KEY_Delete: 
 		{
 			do_remove_node(TRUE);
 			break;
 		}
-		case GDK_Insert: 
+		case GDK_KEY_Insert: 
 		{
 			break;
 		}
-		case GDK_F2:
+		case GDK_KEY_F2:
 		{
 			do_rename_node(TRUE);
 			return TRUE;
 			break;
 		}
-		case GDK_F5:
+		case GDK_KEY_F5:
 		{
 			print_filelist();
 			break;
@@ -1227,17 +1229,10 @@ static void collapse_all_items_cb()
  */
 void edit_options_cb()
 {
-	gchar *absFilePath=NULL;
 	GError *err=NULL;
 	gchar *command=NULL;
 	
-	const char *homedir=g_get_home_dir();
-	
-	debug_printf("Home:%s\n",homedir);
-	
-	absFilePath=g_strdup_printf("%s/.sciteproj",homedir);
-	
-	if ((command = g_strdup_printf("open:%s\n", absFilePath)) == NULL) {
+	if ((command = g_strdup_printf("open:%s\n", prefs_filename)) == NULL) {
 		g_set_error(&err, APP_SCITEPROJ_ERROR, -1, "%s: Error formatting Scite director command, g_strdup_printf() = NULL", __func__);
 	}
 	else {
@@ -1251,8 +1246,6 @@ void edit_options_cb()
 			}
 		}
 	}	
-	
-	g_free(absFilePath);
 }
 
 
