@@ -1,6 +1,7 @@
-/* tree_manipulation.c - GtkTreeView manipulation code for SciteProj
+/**
+ * tree_manipulation.c - GtkTreeView manipulation code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -31,26 +32,16 @@
 #include "graphics.h"
 #include "prefs.h"
 
+#include "clicked_node.h"
 
 #include "gui.h"
 
+#include "filelist.h"
+
 
 #define APP_SCITEPROJ_ERROR g_quark_from_static_string("APP_TREEMANIPULATION_ERROR")
 
 
-// The types for each column in the tree datamodel
-
-#define TYPE_ITEMTYPE			G_TYPE_UINT
-#define TYPE_FILEPATH			G_TYPE_STRING
-#define TYPE_FILENAME			G_TYPE_STRING
-#define TYPE_FILESIZE			G_TYPE_STRING
-#define TYPE_FONTWEIGHT			G_TYPE_INT
-#define TYPE_FONTWEIGHTSET		G_TYPE_BOOLEAN
-#define TYPE_ICON					GDK_TYPE_PIXBUF
-#define TYPE_EXPANDED			G_TYPE_BOOLEAN
-	
-
-
 GtkTreeStore *sTreeStore = NULL;
 static gboolean sProjectIsDirty = FALSE;
 static gchar *sProjectFilepath = NULL;
@@ -127,6 +118,7 @@ EXITPOINT:
 	return finalResult;
 }
 
+
 /**
  *
  */
@@ -867,6 +859,8 @@ gboolean add_tree_file(GtkTreeIter *currentIter, enum NodePosition position, con
 	// Extract filename from filepath
 	fileName = get_filename_from_full_path((gchar*)filepath);
 	
+	add_item((gchar*)fileName,(gchar*)relFilename);
+	
 	// Append to root, or before/after/within an existing node?
 	
 	if (currentIter == NULL) {
@@ -907,6 +901,7 @@ gboolean add_tree_file(GtkTreeIter *currentIter, enum NodePosition position, con
 		(strcmp(fileExt,"cpp")==0)
 		) {
 		gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, cpp_file_pixbuf, -1);
+			
 	} else if (
 		(strcmp(fileExt,"hh")==0) ||
 		(strcmp(fileExt,"h++")==0) ||
@@ -914,6 +909,16 @@ gboolean add_tree_file(GtkTreeIter *currentIter, enum NodePosition position, con
 		(strcmp(fileExt,"hpp")==0)
 	) {
 		gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, header_file_pixbuf, -1);
+		
+	} else if (
+		(strcmp(fileExt,"lua")==0) 
+	) {
+		gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, lua_file_pixbuf, -1);
+		
+	} else if (
+		(strcmp(fileExt,"java")==0)
+	) {
+		gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, java_file_pixbuf, -1);
 	} else {
 		gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, txt_file_pixbuf, -1);
 	}
@@ -934,6 +939,47 @@ EXITPOINT:
 }
 
 
+/**
+ *
+ */
+void helper_remove(GtkTreeIter *iter)
+{
+		
+	GtkTreeIter *tempIter=gtk_tree_iter_copy(iter);
+	GtkTreeIter newIter;
+		
+	if (gtk_tree_model_iter_children(GTK_TREE_MODEL(sTreeStore),&newIter,tempIter)) {
+		
+		gboolean next_valid=TRUE;
+		
+		do {
+			
+			if (next_valid) {
+				
+				gchar *nodeContents;
+				int itemType;
+					
+				gtk_tree_model_get(GTK_TREE_MODEL(sTreeStore), &newIter, COLUMN_ITEMTYPE, &itemType, COLUMN_FILEPATH, &nodeContents, -1);
+				
+				gchar *fileName = get_filename_from_full_path((gchar*)nodeContents);
+				
+				if (itemType==ITEMTYPE_GROUP) {
+					helper_remove(&newIter);
+				} else {
+					//printf("Removed: %s, %s\n",fileName,nodeContents);
+					
+					remove_item(fileName,nodeContents);
+				}
+			}
+
+			next_valid=gtk_tree_model_iter_next(GTK_TREE_MODEL(sTreeStore),&newIter);
+			
+		} while(next_valid);
+		
+	}
+	
+}
+
 
 /**
  * Remove a node from the GtkTreeStore.
@@ -945,6 +991,25 @@ EXITPOINT:
  */
 extern gboolean remove_tree_node(GtkTreeIter *iter, GError **err)
 {
+	gchar *file_path;
+	
+	int itemType;
+	
+	// Get the node type and content
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(sTreeStore), iter, COLUMN_ITEMTYPE, &itemType, COLUMN_FILEPATH, &file_path, -1);
+	
+	if (itemType==ITEMTYPE_GROUP) {
+		
+		helper_remove(iter);
+		
+	} else {
+	
+		gchar *fileName = get_filename_from_full_path((gchar*)file_path);
+		
+		remove_item(fileName,file_path);
+	}
+	
 	gtk_tree_store_remove(sTreeStore, iter);
 	
 	set_project_dirty_status(TRUE);
